import gtk; _gtk = gtk; del gtk
import _gtkhtml

HTML_STREAM_OK = 0
HTML_STREAM_ERROR = 1

class GtkHTML (_gtk.GtkLayout):
    get_type = _gtkhtml.gtk_html_get_type
    def __init__ (self, _obj=None):
        if _obj: self._o = _obj; return
        self._o = _gtkhtml.gtk_html_new ()

    def begin (self, url):
        return _gtkhtml.gtk_html_begin (self._o, url)

    def write (self, handle, buf):
        _gtkhtml.gtk_html_write (self._o, handle, buf)

    def end (self, handle, status):
        _gtkhtml.gtk_html_end (self._o, handle, status)

_gtk._name2cls['GtkHTML'] = GtkHTML

